module.exports = defineTest({
	description: 'track deoptimizations of computed properties of empty objects'
});
